@@ -461,82 +461,36 @@ class PlaceLoader(AddressObjectLoaderBase):
 
     _mapper_class = UIAddressObjectMapper
 
+    @property
+    def _filter_param(self):
+        """Query-параметр для фильтрации.
+
+        :rtype: str
+        """
+        return 'name_with_parents'
+
+    def _get_params(self):
+        """Возвращает параметры запроса к серверу ГАР.
+
+        :rtype: dict
+        """
+        filter_param = self._filter_param
+
+        if self.exact:
+            filter_param += '__exact'
+
+        result = {
+            filter_param: f'{self._default_hierarchy}:{self.filter_string}',
+        }
+
+        return result
+
     def _filter(self, object_data):
         return bool(object_data['fullName'])
 
     def _sort_key(self, object_data):
         return object_data['level'], object_data['fullName'] or ''
 
-    def load_raw(self, page=None):
-        from django.conf import (
-            settings,
-        )
-
-        def get_page_counter():
-            if page is None:
-                pages = count(start=1)
-            else:
-                pages = range(page, page + 1)
-
-            return pages
-
-        # Значение PAGE_LIMIT по умолчанию 5. С большим PAGE_LIMIT можно заддосить ГАР
-        page_limit = settings.GAR.get('PAGE_LIMIT', DEFAULT_PAGE_LIMIT)
-
-        # Нам могут передать что-то вроде "Новосибирск, Маяк". В этом случае
-        # все части, кроме последней - это потенциальные фильтры по родителям
-        filter_parts = [x.strip() for x in self.filter_string.split(',') if x]
-        filter_count = len(filter_parts)
-        parent_ids = set()
-
-        for index, part in enumerate(filter_parts, start=1):
-            self.filter_string = part
-
-            if index == filter_count:
-                # Дошли до последнего элемента, будем искать по родителям
-                for parent_id in parent_ids or set([None]):
-                    self._parent_id = parent_id
-                    # Приходится собирать для каждого родителя
-                    params = self._get_params()
-
-                    for page_number in get_page_counter():
-                        drf_data = self._load_page(params, page_number)
-                        if drf_data:
-                            for drf_object_data in drf_data['results']:
-                                object_data = self._process_object_data(drf_object_data)
-                                if self._filter(object_data):
-                                    yield object_data
-
-                            if not drf_data['next'] or page_number >= page_limit:
-                                break
-                        else:
-                            break
-
-            else:
-                # Переопределим родителей, чтобы не плодить их для каждого параметра фильтрации
-                _parent_ids = deepcopy(parent_ids) or set([None])
-                parent_ids = set()
-
-                for _parent_id in _parent_ids:
-                    self._parent_id = _parent_id
-
-                    # Займемся поиском родителей
-                    params = self._get_params()
-
-                    for page_number in count(start=1):
-                        #  Не ограничиваем поиск количеством страниц, чтобы не потерять результаты
-                        drf_data = self._load_page(params, page_number)
-
-                        if drf_data:
-                            for drf_object_data in drf_data['results']:
-                                parent_ids.add(drf_object_data['objectguid'])
-
-                            if not drf_data['next']:
-                                break
-
-                        else:
-                            break
-
 
 class StreetLoader(AddressObjectLoaderBase):
     """
