@@ -59,6 +59,7 @@ class UIHouseMapper(ObjectMapper):
         'buildingNumber': 'building_number',
         'structureNumber': 'structure_number',
         'postalCode': 'postal_code',
+        'houseType': 'house_type',
     }
 
 
@@ -96,6 +97,7 @@ class AddressFields(BaseExtComponent):
             'street_name': 'street_name',
             'street_id': 'street_id',
             'house_number': 'house_number',
+            'house_type': 'house_type',
             'building_number': 'building_number',
             'structure_number': 'structure_number',
             'house_id': 'house_id',
@@ -108,7 +110,7 @@ class AddressFields(BaseExtComponent):
             'place_name': 'Населенный пункт',
             'zip_code': 'Индекс',
             'street_name': 'Улица',
-            'house_number': 'Дом',
+            'house_number': 'Дом (здание)',
             'building_number': 'Корпус',
             'structure_number': 'Строение',
             'flat_number': 'Квартира',
@@ -290,6 +292,7 @@ class AddressFields(BaseExtComponent):
                 'buildingNumber',
                 'structureNumber',
                 'postalCode',
+                'houseType',
             ],
             store=ExtJsonStore(
                 url=self.backend.house_search_url,
@@ -344,6 +347,19 @@ class AddressFields(BaseExtComponent):
             name=self._names_of_fields['house_id'],
         )
 
+#TODO BOBUH-20190 возможно, от этого стоит отказаться или, наоборот, сделать более общим
+    @cached_property
+    def field__house_type(self):
+        """
+        Поле для хранения типа дома
+
+        :rtype: m3_ext.ui.fields.simple.ExtHiddenField
+        """
+        return ExtHiddenField(
+            type=ExtHiddenField.STRING,
+            name=self._names_of_fields['house_type'],
+        )
+
     @cached_property
     def field__flat_number(self):
         """Поле для ввода номера квартиры.
@@ -396,6 +412,7 @@ class AddressFields(BaseExtComponent):
             result.extend((
                 self.field__house_id,
                 self.field__house_number,
+                self.field__house_type,
                 self.field__building_number,
                 self.field__structure_number,
             ))
@@ -486,6 +503,7 @@ class AddressFields(BaseExtComponent):
             put('buildingNumberField', self.field__building_number.render)
             put('structureNumberField', self.field__structure_number.render)
             put('houseIDField', self.field__house_id.render)
+            put('houseTypeField', self.field__house_type.render)
 
             if self.house:
                 house_dict = ObjectDictAdapter(self.house)
@@ -687,6 +705,14 @@ class AdvancedRowsAddressView(RowsAddressView):
 
     house_field_name = property(get_house_field_name, set_house_field_name)
 
+    def get_house_type_field_name(self):
+        return self.fields.names_of_fields['house_type']
+
+    def set_house_type_field_name(self, value):
+        self.fields.names_of_fields['house_type'] = value
+
+    house_type_field_name = property(get_house_type_field_name, set_house_type_field_name)
+
     def get_zipcode_field_name(self):
         return self.fields.names_of_fields['zip_code']
 
